@@ -9,7 +9,6 @@ from algosdk.abi.contract import NetworkInfo
 from algosdk.error import (
     ABITypeError,
     AtomicTransactionComposerError,
-    IndexerHTTPError,
 )
 from algosdk.future import transaction
 from behave import given, step, then, when
@@ -143,69 +142,11 @@ def search_application2(context, creator):
     context.response = context.icl.search_applications(creator=creator)
 
 
-@when(
-    'I use {indexer} to search for applications with {limit}, {application_id}, "{include_all:MaybeBool}" and token "{token:MaybeString}"'
-)
-def search_applications_include_all(
-    context, indexer, limit, application_id, include_all, token
-):
-    context.response = context.icls[indexer].search_applications(
-        application_id=int(application_id),
-        limit=int(limit),
-        include_all=include_all,
-        next_page=token,
-    )
-
-
-@when(
-    'I use {indexer} to search for applications with {limit}, {application_id}, and token "{token:MaybeString}"'
-)
-def search_applications(context, indexer, limit, application_id, token):
-    context.response = context.icls[indexer].search_applications(
-        application_id=int(application_id), limit=int(limit), next_page=token
-    )
-
-
-@when(
-    'I use {indexer} to lookup application with {application_id} and "{include_all:MaybeBool}"'
-)
-def lookup_application_include_all2(
-    context, indexer, application_id, include_all
-):
-    try:
-        context.response = context.icls[indexer].applications(
-            application_id=int(application_id), include_all=include_all
-        )
-    except IndexerHTTPError as e:
-        context.response = json.loads(str(e))
-
-
 @when("we make a LookupApplications call with applicationID {app_id}")
 def lookup_application(context, app_id):
     context.response = context.icl.applications(int(app_id))
 
 
-@when("I use {indexer} to lookup application with {application_id}")
-def lookup_application2(context, indexer, application_id):
-    context.response = context.icls[indexer].applications(
-        application_id=int(application_id)
-    )
-
-
-@when("we make a SearchForApplications call with {application_id} and {round}")
-def search_applications2(context, application_id, round):
-    context.response = context.icl.search_applications(
-        application_id=int(application_id), round=int(round)
-    )
-
-
-@when("we make a LookupApplications call with {application_id} and {round}")
-def lookup_applications(context, application_id, round):
-    context.response = context.icl.applications(
-        application_id=int(application_id), round=int(round)
-    )
-
-
 @when(
     'I build an application transaction with operation "{operation:MaybeString}", application-id {application_id}, sender "{sender:MaybeString}", approval-program "{approval_program:MaybeString}", clear-program "{clear_program:MaybeString}", global-bytes {global_bytes}, global-ints {global_ints}, local-bytes {local_bytes}, local-ints {local_ints}, app-args "{app_args:MaybeString}", foreign-apps "{foreign_apps:MaybeString}", foreign-assets "{foreign_assets:MaybeString}", app-accounts "{app_accounts:MaybeString}", fee {fee}, first-valid {first_valid}, last-valid {last_valid}, genesis-hash "{genesis_hash:MaybeString}", extra-pages {extra_pages}'
 )
@@ -413,14 +354,16 @@ def wait_for_algod_transaction_processing_to_complete():
     time.sleep(0.5)
 
 
+# TODO: this needs to be modified to use v2 only
 @step("I wait for the transaction to be confirmed.")
 def wait_for_app_txn_confirm(context):
     wait_for_algod_transaction_processing_to_complete()
     if hasattr(context, "acl"):
+        # TODO: get rid of this branch of logic when v1 fully deprecated
         assert "type" in context.acl.transaction_info(
             context.transient_pk, context.app_txid
         )
-        assert "type" in context.acl.transaction_by_id(context.app_txid)
+        # assert "type" in context.acl.transaction_by_id(context.app_txid)
     else:
         transaction.wait_for_confirmation(context.app_acl, context.app_txid, 1)
 
